/** observable.dart --- Inheritable class.
 *
 * Copyright (C) 2014  Miguel Guedes
 * 
 * Author: Miguel Guedes <miguel.a.guedes@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see http://www.gnu.org/licenses/.
 *
 * Comments:
 *
 * 
 */

import 'observer_events.dart';
import 'observer.dart';


/** Extend from this class to permit clients to register to receive
 * notifications of events.
 *
 * Usage:
 *
 *  Instantiation
 *  
 *    class Foo extends Observable
 *      ...
 *
 *  Register for an event
 *
 *    Foo foo = new Foo();
 *    foo.on.anEvent(() => print("Notification received for `anEvent'");
 *
 *  Dispatch notification of an event
 *
 *    observer.dispatch("anEvent");
 */
class Observable
{
  Observer        observer;     /* This is really a PROTECTED attribute,
                                 * although Dart only supports public and
                                 * private visibility. */
  ObserverEvents  on;


  Observable()
    : observer = new Observer()
  {
    on = observer.on;
  }
}

