/** observer-events.dart --- Routes event register requests to an Observer
 *  instance.
 *
 * Copyright (C) 2014  Miguel Guedes
 * 
 * Author: Miguel Guedes <miguel.a.guedes@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see http://www.gnu.org/licenses/.
 *
 * Comments:
 *
 * 
 */


import 'observer_exception.dart';


/** Internal class. Routes event register requests to an Observer instance.
 */
class ObserverEvents
{
  Observer _owner;

  
  ObserverEvents(final Observer owner)
    : _owner = owner
  { }
  
  bool noSuchMethod(final Invocation invocation)
  {
    final List args = invocation.positionalArguments;
    
    /* We assume an attempt is being made to register for an event. */
    if(!invocation.isMethod)
      throw new ObserverException("Invalid invocation");
    else if(args.length != 1)
      throw new ObserverException("Number of arguments invalid");
    else if(!(args[0] is Function))
      throw new ObserverException("Invalid observer function");

    return _owner.add(
        (new RegExp("\"(.+)\""))
          .firstMatch(invocation.memberName.toString())[1],
        invocation.positionalArguments[0]);
  }
}
